@@ -32,7 +32,7 @@ config = {
     'bag_create_policy': 'ANY',
     'recipe_create_policy': 'ANY',
     'css_uri': '/bags/common/tiddlers/tiddlyweb.css',
-    'socialusers.reserved_names': ['www', 'about', 'help', 'announcements',
+    'socialusers.reserved_names': ['www', 'about', 'announcements',
         'dev', 'info', 'api', 'status', 'login', 'frontpage'],
     'cookie_age': '2592000',  # 1 month
     'server_store': ['tiddlywebplugins.tiddlyspace.store', {
